Module online_learning

Module online_learning 

Online learning algorithms: Perceptron, Passive-Aggressive, OGD, and FTRL.

All algorithms process one sample at a time with O(d) memory where d is the number of features, making them suitable for streaming and large-scale applications where the full dataset cannot be held in memory.

Algorithms

Structs

Ftrl
Follow the Regularized Leader — Proximal (McMahan et al. 2013).
OnlineGradientDescent
Online Gradient Descent for convex losses.
OnlineStats
Cumulative statistics for an online learning session.
OnlineUpdateResult
Result of a single online update step.
PassiveAggressive
Passive-Aggressive classifier (Crammer et al. 2006).
Perceptron
Binary Perceptron classifier (Rosenblatt 1958).

Enums

OGDLoss
Loss function for OnlineGradientDescent.
OnlineError
Errors that can arise in online learning routines.
PAVariant
Selects the PA update variant.

Traits

OnlineLearner
Trait for online learners that update one sample at a time.

Functions

online_evaluate
Evaluate an online learner sequentially on a dataset.