pub struct EarlyStoppingMonitor { /* private fields */ }Expand description
The early stopping monitor.
Tracks a single metric over epochs and decides when to stop training based on patience, minimum delta, baseline, and minimum epoch constraints.
Implementations
Sourceimpl EarlyStoppingMonitor
impl EarlyStoppingMonitor
Sourcepub fn new(config: EarlyStoppingConfig) -> Self
pub fn new(config: EarlyStoppingConfig) -> Self
Create a new monitor with the given configuration.
Sourcepub fn with_default() -> Self
pub fn with_default() -> Self
Create a new monitor with default configuration.
Sourcepub fn step(&mut self, metric_value: f64) -> EarlyStoppingDecision
pub fn step(&mut self, metric_value: f64) -> EarlyStoppingDecision
Report the metric for the current epoch and return a decision.
This advances the epoch counter, records the metric value, and evaluates whether training should continue or stop.
Sourcepub fn should_stop(&self) -> bool
pub fn should_stop(&self) -> bool
Check if training should stop (without advancing epoch).
Sourcepub fn best_value(&self) -> Option<f64>
pub fn best_value(&self) -> Option<f64>
Best metric value seen so far.
Sourcepub fn best_epoch(&self) -> usize
pub fn best_epoch(&self) -> usize
Epoch at which the best value was seen.
Sourcepub fn current_epoch(&self) -> usize
pub fn current_epoch(&self) -> usize
Current epoch number.
Sourcepub fn epochs_since_improvement(&self) -> usize
pub fn epochs_since_improvement(&self) -> usize
Number of epochs since last improvement.